@@ -2,8 +2,10 @@ pub mod config;
 pub mod list;
 pub mod template;
 pub mod consts;
+pub mod error;
 
 pub use config::*;
 pub use list::*;
 pub use template::*;
-pub use consts::*;
\ No newline at end of file
+pub use consts::*;
+pub use error::*;
\ No newline at end of file
